ExRTCP.Packet.SourceDescription.Chunk.Item (ex_rtcp v0.4.1)

Item contained by chunks in Source Description RTCP packets.

Includes items specified by RFC 3550 as well as the MID SDES item specified in RFC 8843.

Summary

Types

t()

Struct representing item contained by chunks in Source Description RTCP packets.

Types

item_type()

@type item_type() ::
  :cname
  | :name
  | :email
  | :phone
  | :location
  | :tool
  | :note
  | :priv
  | :mid
  | :rtp_stream_id
  | :repaired_rtp_stream_id

t()

@type t() :: %ExRTCP.Packet.SourceDescription.Chunk.Item{
  text: binary(),
  type: item_type()
}

Struct representing item contained by chunks in Source Description RTCP packets.

Text must be shorter than 256 bytes.